import { Motion } from '@capacitor/motion';
import { useEffect } from 'react';
import { PACKAGE_NAME } from '../../package-name';
import createDebugMessages from 'debug';
import { getSubscriptionHandler } from '../get-subscription-handler';
/**
 * This hook subscribes to the acceleration event and saves the data to Deep
 *
 * @remarks
 * It is not recommended to use this hook directly. Instead of {@link WithUseAccelerationSubscription}
 *
 * @example
```ts
useAccelerationSubscription({
  deep,
  containerLinkId
})
```
 */
export function useAccelerationSubscription(param) {
    const debug = createDebugMessages(`${PACKAGE_NAME}:useAccelerationSubscription`);
    debug({ param });
    const { deep, containerLinkId } = param;
    useEffect(() => {
        const accelerationHandlerFunction = getSubscriptionHandler({
            deep,
            containerLinkId,
        });
        const accelerationHandler = Motion.addListener('accel', accelerationHandlerFunction);
        debug({ accelerationHandler });
        return () => {
            accelerationHandler.remove();
        };
    }, [deep, containerLinkId]);
}
